@@ -177,7 +177,7 @@ static void avl_free_nodes(avl_tree_t *avltree) {
       freeitem(node->item);
     free(node);
   }
-  return avl_clear_tree(avltree);
+  avl_clear_tree(avltree);
 }
 
 static void avl_free_tree(avl_tree_t *avltree) {
@@ -714,12 +714,13 @@ SEXP do_hv(SEXP s_data, SEXP s_ref) {
   UNPACK_REAL_MATRIX(s_data, data, k_data, n_data);
   UNPACK_REAL_VECTOR(s_ref, ref, n_ref);
 
+  if (n_ref != k_data)
+    error("ref and data must be same dimension.");
+
   /* Allocate result */
   PROTECT(s_res = allocVector(REALSXP, 1));
   double *res = REAL(s_res);
 
-  Rprintf("%2ix%2i\n", n_data, k_data);
-
   bound = Calloc(k_data, double);
   for (i = 0; i < k_data; i++) 
     bound[i] = -DBL_MAX;
